@@ -48,7 +48,8 @@ enum Optcode {
         S_OPT_PRINT_STYLE, S_OPT_NO_TRAILING_NL, S_OPT_PLUGIN, S_OPT_ABS_CFG_PATH,
         S_OPT_PLUGIN_READFILE, S_OPT_PLUGIN_PARAMETER, S_OPT_LIST_SCRIPTS, S_OPT_CANVAS,
         S_OPT_KEEP_INJECTIONS, S_OPT_FORCE_STDOUT, S_OPT_LATEX_BEAMER, S_OPT_NO_VERSION_INFO,
-        S_OPT_REFORMAT_OPT, S_OPT_RANGE_OPT, S_OPT_BASE16, S_OPT_CATEGORIES
+        S_OPT_REFORMAT_OPT, S_OPT_RANGE_OPT, S_OPT_BASE16, S_OPT_CATEGORIES, S_OPT_PIPED_FNAME,
+        S_OPT_ISOLATE
     };
 
 const Arg_parser::Option options[] = {
@@ -76,7 +77,6 @@ const Arg_parser::Option options[] = {
         { 'N', OPT_ANCHOR_FN,      Arg_parser::no  },
         { 'o', OPT_OUT,            Arg_parser::yes },
         { 'O', OPT_OUTFORMAT, 	   Arg_parser::yes },
-        { 'p', OPT_LISTLANGS,      Arg_parser::no  },
         { 'P', OPT_PROGRESSBAR,    Arg_parser::no  },
         { 'q', OPT_QUIET,          Arg_parser::no  },
         { 'Q', OPT_VERSION,        Arg_parser::no  },
@@ -88,7 +88,6 @@ const Arg_parser::Option options[] = {
         { 'u', OPT_ENCODING,       Arg_parser::yes },
         { 'v', OPT_VERBOSE,        Arg_parser::no  },
         { 'V', OPT_WRAPSIMPLE,     Arg_parser::no  },
-        { 'w', OPT_LISTTHEMES,     Arg_parser::no  },
         { 'W', OPT_WRAP,           Arg_parser::no  },
         { 'x', OPT_RTF_PAGE_SIZE,  Arg_parser::yes },
         { 'y', OPT_ANCHOR_PFX,     Arg_parser::yes },
@@ -120,7 +119,7 @@ const Arg_parser::Option options[] = {
         { S_OPT_PRETTY_SYMBOLS,   OPT_PRETTY_SYMBOLS,  Arg_parser::no },
         { S_OPT_EOL_DELIM_CR,     OPT_EOL_DELIM_CR,    Arg_parser::no },
         { S_OPT_PRINT_STYLE,      OPT_PRINT_STYLE,     Arg_parser::no },
-        { S_OPT_BASE16,           OPT_BASE16,          Arg_parser::no },
+        { S_OPT_BASE16,           OPT_BASE16,          Arg_parser::maybe },
         { S_OPT_NO_TRAILING_NL,   OPT_NO_TRAILING_NL,  Arg_parser::no },
         { S_OPT_KEEP_INJECTIONS,  OPT_KEEP_INJECTIONS, Arg_parser::no },
         { S_OPT_FORCE_STDOUT,     OPT_FORCE_STDOUT,    Arg_parser::no },
@@ -136,6 +135,9 @@ const Arg_parser::Option options[] = {
         { S_OPT_REFORMAT_OPT,     OPT_REFORMAT_OPT,    Arg_parser::yes },
         { S_OPT_RANGE_OPT,        OPT_RANGE_OPT,       Arg_parser::yes },
         { S_OPT_CATEGORIES,       OPT_CATEGORIES,      Arg_parser::yes },
+        { S_OPT_PIPED_FNAME,      OPT_PIPED_FNAME,     Arg_parser::yes },
+        { S_OPT_ISOLATE,          OPT_ISOLATE_TAGS,    Arg_parser::no },
+        
 
         { 0, 0, Arg_parser::no }
     };
@@ -162,13 +164,9 @@ CmdLineOptions::CmdLineOptions ( const int argc, const char *argv[] ) :
     opt_verbose ( false ),
     opt_print_config ( false ),
     opt_linenumbers ( false ),
-    opt_style ( false ),
     opt_batch_mode ( false ),
     opt_fragment ( false ) ,
     opt_attach_line_anchors ( false ),
-    opt_show_themes ( false ),
-    opt_show_langdefs ( false ),
-    opt_show_plugins (false),
     opt_printindex ( false ),
     opt_quiet ( false ),
     opt_replacequotes ( false ),
@@ -195,6 +193,7 @@ CmdLineOptions::CmdLineOptions ( const int argc, const char *argv[] ) :
     opt_force_stdout(false),
     opt_no_version_info(false),
     explicit_output_format(false),
+    opt_isolate(false),
     anchorPrefix ( "l" ),
     helpLang ( "en" ),
     encodingName ( "ISO-8859-1" )
@@ -385,9 +384,6 @@ void CmdLineOptions::parseRuntimeOptions( const int argc, const char *argv[], bo
             explicit_output_format=true;
             outDirectory = validateDirPath ( arg );
             break;
-        case 'p':
-            opt_show_langdefs = true;
-            break;
         case 'P':
             opt_print_progress=true;
             break;
@@ -402,7 +398,6 @@ void CmdLineOptions::parseRuntimeOptions( const int argc, const char *argv[], bo
             break;
         case 's':
             styleName = arg;
-            opt_style = true;
             break;
         case 'S':
         case S_OPT_COMPAT_SRCLANG:
@@ -422,9 +417,6 @@ void CmdLineOptions::parseRuntimeOptions( const int argc, const char *argv[], bo
         case 'V':
             wrappingStyle = highlight::WRAP_SIMPLE;
             break;
-        case 'w':
-            opt_show_themes = true;
-            break;
         case 'W':
             wrappingStyle = highlight::WRAP_DEFAULT;
             break;
@@ -463,7 +455,6 @@ void CmdLineOptions::parseRuntimeOptions( const int argc, const char *argv[], bo
                 keywordCase = StringTools::CASE_CAPITALIZE;
         }
         break;
-
         case S_OPT_PRINT_CONFIG:
             opt_print_config = true;
             break;
@@ -479,7 +470,6 @@ void CmdLineOptions::parseRuntimeOptions( const int argc, const char *argv[], bo
         case S_OPT_RTF_PAGE_COLOR:
              opt_page_color=true;
             break;
-          
         case S_OPT_SKIP_UNKNOWN:
             skipArg=arg;
             break;
@@ -522,6 +512,8 @@ void CmdLineOptions::parseRuntimeOptions( const int argc, const char *argv[], bo
             break;
         case S_OPT_BASE16:
             opt_base16_theme = true;
+            if (!arg.empty())
+                styleName = arg;
             break;
         case S_OPT_NO_TRAILING_NL:
             opt_no_trailing_nl = true;
@@ -554,9 +546,7 @@ void CmdLineOptions::parseRuntimeOptions( const int argc, const char *argv[], bo
             break;
         }
         case S_OPT_LIST_SCRIPTS:
-            opt_show_themes=(arg=="themes");
-            opt_show_plugins=(arg=="plugins");
-            opt_show_langdefs=!(opt_show_themes&&opt_show_plugins);
+            listScriptType=arg;
             break;
         case S_OPT_CANVAS:
             canvasPaddingWidth=80;
@@ -566,7 +556,15 @@ void CmdLineOptions::parseRuntimeOptions( const int argc, const char *argv[], bo
             break;
             
         case S_OPT_CATEGORIES:
-            categories=arg;
+            listScriptCategory=arg;
+            if (listScriptType.empty()) listScriptType = "langs";
+            break;
+        case S_OPT_PIPED_FNAME:
+            redirectedFilename=arg;
+            opt_syntax=true;
+            break;
+        case S_OPT_ISOLATE:
+            opt_isolate=true;
             break;
         default:
             cerr << "highlight: option parsing failed" << endl;
@@ -686,12 +684,21 @@ bool CmdLineOptions::printLineNumbers() const
 
 string CmdLineOptions::getThemeName() const
 {
-    return ( ( opt_style ) ? styleName+".theme" : (outputType==highlight::ESC_XTERM256 || outputType==highlight::ESC_TRUECOLOR)?"edit-vim-dark.theme":"edit-kwrite.theme" );
+    if (!styleName.empty())
+        return styleName+".theme";
+    
+    bool isEscOutput = outputType==highlight::ESC_XTERM256 || outputType==highlight::ESC_TRUECOLOR;
+    if (opt_base16_theme)
+        return isEscOutput ? "harmonic-dark.theme" : "harmonic-light.theme";
+    
+    return isEscOutput ? "edit-vim-dark.theme" : "edit-kwrite.theme";
 }
+
 bool CmdLineOptions::enableBatchMode() const
 {
     return inputFileNames.size() >1 || opt_batch_mode;
 }
+
 bool CmdLineOptions::fragmentOutput() const
 {
     return opt_fragment;
@@ -701,6 +708,11 @@ bool CmdLineOptions::omitVersionInfo() const {
     return opt_no_version_info;    
 }
 
+bool CmdLineOptions::isolateTags() const
+{
+    return opt_isolate;
+}
+
 string CmdLineOptions::getOutFileSuffix() const
 {
     switch ( outputType ) {
@@ -735,18 +747,6 @@ bool CmdLineOptions::attachLineAnchors() const
 {
     return opt_attach_line_anchors;
 }
-bool CmdLineOptions::showThemes() const
-{
-    return opt_show_themes;
-}
-bool CmdLineOptions::showLangdefs() const
-{
-    return opt_show_langdefs;
-}
-bool CmdLineOptions::showPlugins() const
-{
-    return opt_show_plugins;
-}
 bool CmdLineOptions::outDirGiven() const
 {
     return !outFilename.empty();
@@ -989,9 +989,17 @@ int CmdLineOptions::getLineRangeEnd()
 }
 
 const string& CmdLineOptions::getCategories() const {
-    return categories;
+    return listScriptCategory;
 }
 
 const string& CmdLineOptions::getHelpTopic() const {
     return helpTopic;
 }
+
+const string& CmdLineOptions::getSyntaxByFilename() const {
+    return redirectedFilename;
+}
+
+const string& CmdLineOptions::getListScriptKind() const{
+    return listScriptType;
+}
