@@ -70,8 +70,6 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 #define OPT_KW_CASE        "kw-case"
 #define OPT_LINENO         "line-numbers"
 #define OPT_LINE_LEN       "line-length"
-#define OPT_LISTLANGS      "list-langs"
-#define OPT_LISTTHEMES     "list-themes"
 #define OPT_LIST_SCRIPTS   "list-scripts"
 #define OPT_LNR_LEN        "line-number-length"
 #define OPT_LNR_START      "line-number-start"
@@ -114,6 +112,9 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 #define OPT_REFORMAT_OPT     "reformat-option"
 #define OPT_RANGE_OPT        "line-range"
 #define OPT_BASE16           "base16"
+#define OPT_CATEGORIES       "list-cat"  
+#define OPT_PIPED_FNAME      "syntax-by-name"
+#define OPT_ISOLATE_TAGS     "isolate"
 
 // Improve CLI option compatibility with GNU source-highlight
 #define OPT_COMPAT_DOC       "doc"
@@ -125,7 +126,6 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 #define OPT_COMPAT_SRCLANG   "src-lang"
 #define OPT_COMPAT_LINENUM   "line-number"
 #define OPT_COMPAT_LINEREF   "line-number-ref"
-#define OPT_CATEGORIES       "list-cat"  
 
 using namespace std;
 
@@ -208,15 +208,6 @@ public:
     /** \return True if anchors should be attached to line numbers*/
     bool attachLineAnchors() const;
 
-    /** \return True if list of installed themes should be printed*/
-    bool showThemes() const;
-
-    /** \return True if list of installed language definitions should be printed*/
-    bool showLangdefs() const;
-
-    /** \return True if list of installed language definitions should be printed*/
-    bool showPlugins() const;
-
     /** \return True if loutput directory is given*/
     bool outDirGiven() const;
 
@@ -328,6 +319,9 @@ public:
     /** \return True if Base16 theme should be used */
     bool useBase16Theme() const;
 
+    /** \return True if output token of the same syntax category should be in separate tags */
+    bool isolateTags() const;
+    
     /** \return The given base font, empty string by default */
     const string& getBaseFont() const ;
 
@@ -364,12 +358,18 @@ public:
     /** \return parameter passed to plugin */
     const string& getPluginParameter() const ;
 
-    /** \return categories sepatated by X to filter scripts in --list-scripts */
+    /** \return category to filter scripts of --list-scripts */
     const string& getCategories() const ;
-    
+
     /** \return optional help topic */
     const string& getHelpTopic() const;
 
+    /** \return name of the file which will later be redirected to highlight's stdin */
+    const string& getSyntaxByFilename() const;
+
+    /** \return category of scripts which should be listed */
+    const string& getListScriptKind() const;
+
     /** \return line number width */
     int getNumberWidth();
 
@@ -445,13 +445,9 @@ private:
     bool opt_verbose;
     bool opt_print_config;
     bool opt_linenumbers;
-    bool opt_style;
     bool opt_batch_mode;
     bool opt_fragment;
     bool opt_attach_line_anchors;
-    bool opt_show_themes;
-    bool opt_show_langdefs;
-    bool opt_show_plugins;
     bool opt_printindex;
     bool opt_quiet;
     bool opt_replacequotes;
@@ -478,12 +474,13 @@ private:
     bool opt_force_stdout;
     bool opt_no_version_info;
     bool explicit_output_format;
+    bool opt_isolate;
 
     string anchorPrefix;
     string helpLang, encodingName;
 
     string pluginPath, pluginParameter, 
-           categories, helpTopic;
+           listScriptCategory, helpTopic, redirectedFilename, listScriptType;
 
     /** list of all input file names */
     vector <string> inputFileNames;
