@@ -132,6 +132,8 @@ void printHelp(const std::string &topic)
         cout<<" -P, --progress                 print progress bar in batch mode\n";
         cout<<" -q, --quiet                    supress progress info in batch mode\n";
         cout<<" -S, --syntax=<type>            specify type of source code\n";
+        cout<<"     --syntax-by-name=<name>    specify type of source code by given name\n";
+        cout<<"                                  will not read a file of this name, useful for stdin\n";
         cout<<" -v, --verbose                  print debug info\n";
         cout<<"     --force                    generate output if input syntax is unknown\n";
         cout<<"     --list-scripts=<type>      list installed scripts\n";
@@ -191,8 +193,9 @@ void printHelp(const std::string &topic)
         cout<<"     --wrap-no-numbers          omit line numbers of wrapped lines\n";
         cout<<"                                  (assumes -l)\n";
         cout<<" -z, --zeroes                   pad line numbers with 0's\n";
-        cout<<"     --base16                   use a theme of the Base16 collection\n";
+        cout<<"     --base16[=theme]           use a theme of the Base16 collection\n";
         cout<<"     --delim-cr                 set CR as end-of-line delimiter (MacOS 9)\n";
+        cout<<"     --isolate                  output each syntax token separately (verbose output)\n";
         cout<<"     --keep-injections          output plug-in injections in spite of -f\n";
         cout<<"     --kw-case=<case>           change case of case insensitive keywords\n";
         cout<<"                                  <case> =  [upper, lower, capitalize]\n";
