@@ -3,7 +3,7 @@
                              -------------------
     begin                : Mo 16.03.2009
     copyright            : (C) 2009-2018 by Andre Simon
-    email                : andre.simon1@gmx.de
+    email                : a.simon@mailbox.org
  ***************************************************************************/
 
 /*
@@ -52,6 +52,7 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 #include <QTime>
 #include <QShortcut>
 #include <QString>
+#include <QList>
 #include <QTextStream>
 #include <QFileSystemWatcher>
 #include <QDesktopServices>
@@ -91,7 +92,9 @@ private:
     QFileSystemWatcher scriptWatcher;
     QStringList themesClassic;
     QStringList themesBase16;
-    int themesClassicIdx, themesBase16Idx;
+    QList< QList<QString> > themesList;
+
+    int oldThemeIndex;
 
     bool getDataFromCP;
 
@@ -108,6 +111,8 @@ private:
     QString getDistFileConfigPath();
     QString getDistFileFilterPath();
 
+    QString getWindowsShortPath(const QString & path);
+
     void applyCtrlValues(highlight::CodeGenerator* generator, bool previewMode);
     void selectSingleFile(QLineEdit*, const QString&, const QString&);
     bool loadFileTypeConfig();
@@ -118,7 +123,7 @@ private:
     string getFileSuffix(const string& fileName);
     string getFileBaseName(const string& fileName);
     void readLuaList(const string& paramName, const string& langName, Diluculum::LuaValue &luaVal, MMap* extMap);
-    void fillThemeCombo();
+    void fillThemeCombo(int);
     void showHelpFile(const QString& file);
 
     void dragEnterEvent(QDragEnterEvent *event);
@@ -175,10 +180,8 @@ private slots:
     void on_lvUserScripts_itemClicked(QListWidgetItem *item);
     void on_lvPluginScripts_itemClicked(QListWidgetItem *item);
 
-    void on_comboTheme_activated(int index);
-    void on_cbUseBase16_clicked();
-
     void on_browserPreview_selectionChanged();
+    void on_comboThemeFilter_currentIndexChanged(int index);
 };
 
 #endif // MAINWINDOW_H
