@@ -2,8 +2,8 @@
                           syntaxreader.h  -  description
                              -------------------
     begin                : Wed Nov 28 2001
-    copyright            : (C) 2001-2017 by Andre Simon
-    email                : andre.simon1@gmx.de
+    copyright            : (C) 2001-2019 by Andre Simon
+    email                : a.simon@mailbox.org
  ***************************************************************************/
 
 
@@ -180,6 +180,12 @@ public:
     {
         return langDesc;
     }
+    
+    const string & getCategoryDescription() const
+    {
+        return categories;
+    }
+
 
     /** \return header string defined by a plug-in */
     const string & getHeaderInjection () const
@@ -316,7 +322,7 @@ private:
     string currentPath;
 
     // Language description
-    string langDesc;
+    string langDesc, categories;
 
     string headerInjection, footerInjection;
 
@@ -405,6 +411,7 @@ public:
     RegexElement ( State oState, State eState, const string&rePattern, unsigned int cID=0, int group=-1, const string& name="" ) :
         open ( oState ), end ( eState ), kwClass ( cID ), capturingGroup ( group ), langName(name),instanceId(instanceCnt++)
     {
+        pattern=rePattern;
         rex=boost::xpressive::sregex::compile(rePattern);
     }
 
@@ -419,17 +426,19 @@ public:
     unsigned int kwClass;        ///< keyword class
     int capturingGroup;          ///< capturing group ID
     string langName;             ///< language name
+    string pattern;
     static int instanceCnt;
     int instanceId;
 };
 
 /**\brief Association of a regex and its relevant capturing group
 */
+/*
 struct RegexDef {
     RegexDef() :capturingGroup ( -1 ) {}
     string reString;     ///< regex string
     int capturingGroup;  ///< capturing group which should be recognized as token
-};
+};*/
 
 }
 #endif
